@@ -1,4 +1,4 @@
-/* $Id: freebind.c 42658 2014-12-08 10:48:21Z wsl $ */
+/* $Id: freebind.c 42664 2014-12-08 14:17:23Z wsl $ */
 /* $URL: https://svn.uvt.nl/its-id/trunk/sources/freebind/freebind.c $ */
 
 #define _GNU_SOURCE
@@ -22,13 +22,8 @@ extern void libfreebind_init(void);
 __attribute__((constructor))
 void libfreebind_init(void) {
 	const char *error;
-	union {
-		int (*f)(int, __CONST_SOCKADDR_ARG, socklen_t);
-		void *p;
-	} cast;
 	dlerror();
-	cast.p = dlsym(RTLD_NEXT, "bind");
-	libc_bind = cast.f;
+	libc_bind = dlsym(RTLD_NEXT, "bind");
 	error = dlerror();
 	if(error)
 		(void)write(STDERR_FILENO, error, strlen(error));
